---
name: Feature Request
about: '"It would be really cool if x did y..."'
title: ''
labels: ''
assignees: ''

---

## Use Case
*Please provide a use case to help us understand your request in context*




## Solution
*Please describe your ideal solution*




## Alternatives
*Please describe any alternatives you've considered, even if you've dismissed them*
